envvault edit — open secrets in an editor.
Decrypts all secrets to a temporary file, launches $VISUAL / $EDITOR / vi,
and applies any changes back to the vault on save.
Functions
- execute
- Execute the
editcommand. - parse_
edited_ content - Parse edited content back into a key-value map.