CLI module — Clap argument parser, output helpers, and command implementations.
Modules
- commands
- env_
parser - Shared
.envfile parsing logic. - gitignore
- Shared
.gitignorepatching logic. - output
- Colored terminal output helpers.
Structs
- Cli
- EnvVault CLI: encrypted environment variable manager.
Enums
- Auth
Action - Auth subcommands for keyring and keyfile management.
- Commands
- All available subcommands.
- EnvAction
- Env subcommands for environment management.
Functions
- load_
keyfile - Load the keyfile bytes from the path in CLI args, if provided.
- prompt_
new_ password - Prompt for a new password with confirmation (used during
init). - prompt_
password - Get the vault password, trying in order:
- prompt_
password_ for_ vault - Get the vault password with an optional vault path for keyring lookup.
- validate_
env_ name - Validate that an environment name is safe and sensible.
- vault_
path - Build the full path to a vault file from the CLI arguments.