pub struct MasterKey { /* private fields */ }Expand description
A wrapper around a 32-byte master key that automatically zeroes its memory when dropped.
Use this to hold the master key in memory so it cannot linger after it is no longer needed.
Implementations
Sourceimpl MasterKey
impl MasterKey
Sourcepub fn as_bytes(&self) -> &[u8; 32]
pub fn as_bytes(&self) -> &[u8; 32]
Access the raw key bytes (e.g. to pass to HKDF or encryption).
Sourcepub fn derive_secret_key(&self, secret_name: &str) -> Result<[u8; 32]>
pub fn derive_secret_key(&self, secret_name: &str) -> Result<[u8; 32]>
Derive a per-secret encryption key from this master key.
Sourcepub fn derive_hmac_key(&self) -> Result<[u8; 32]>
pub fn derive_hmac_key(&self) -> Result<[u8; 32]>
Derive an HMAC key from this master key.